package Qt::WebKit::QWebHistoryInterface;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QWebHistoryInterface
# file     : QtWebKit/qwebhistoryinterface.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_02';
our $ISA     = qw/Qt::Core::QObject/;


# FIXME: operator overload


1;

=head1 NAME

Qt::WebKit::QWebHistoryInterface

=head1 PUBLIC METHODS

=over

=item   QWebHistoryInterface()

=item   QWebHistoryInterface( = 0)

=item   ~QWebHistoryInterface()

=item  void addHistoryEntry()

=item  static QWebHistoryInterface * defaultInterface()

=item  bool historyContains()

=item  static void setDefaultInterface()


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
